next/master boot bisection: next-20181219 on rk3399-gru-kevin

kernelci.org bot bot at kernelci.org
Thu Dec 20 04:06:50 UTC 2018


* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* This automated bisection report was sent to you on the basis  *
* that you may be involved with the breaking commit it has      *
* found.  No manual investigation has been done to verify it,   *
* and the root cause of the problem may be somewhere else.      *
* Hope this helps!                                              *
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

next/master boot bisection: next-20181219 on rk3399-gru-kevin

Summary:
  Start:      02fc169594e9 Add linux-next specific files for 20181219
  Details:    https://kernelci.org/boot/id/5c1a267359b51498440a81ab
  Plain log:  https://storage.kernelci.org//next/master/next-20181219/arm64/defconfig/lab-collabora/boot-rk3399-gru-kevin.txt
  HTML log:   https://storage.kernelci.org//next/master/next-20181219/arm64/defconfig/lab-collabora/boot-rk3399-gru-kevin.html
  Result:     641fb0efbff0 iommu/of: Don't call iommu_ops->add_device directly

Checks:
  revert:     PASS
  verify:     PASS

Parameters:
  Tree:       next
  URL:        http://git.kernel.org/pub/scm/linux/kernel/git/next/linux-next.git
  Branch:     master
  Target:     rk3399-gru-kevin
  CPU arch:   arm64
  Lab:        lab-collabora
  Config:     defconfig
  Test suite: boot

Breaking commit found:

-------------------------------------------------------------------------------
commit 641fb0efbff063ed57f108c2eb4a4d26dbd5badd
Author: Joerg Roedel <jroedel at suse.de>
Date:   Wed Dec 5 14:39:45 2018 +0100

    iommu/of: Don't call iommu_ops->add_device directly
    
    Make sure to invoke this call-back through the proper
    function of the IOMMU-API.
    
    Signed-off-by: Joerg Roedel <jroedel at suse.de>

diff --git a/drivers/iommu/of_iommu.c b/drivers/iommu/of_iommu.c
index dbe73456f1a1..d8947b28db2d 100644
--- a/drivers/iommu/of_iommu.c
+++ b/drivers/iommu/of_iommu.c
@@ -222,10 +222,10 @@ const struct iommu_ops *of_iommu_configure(struct device *dev,
 	}
 	/*
 	 * If we have reason to believe the IOMMU driver missed the initial
 	 * add_device callback for dev, replay it to get things in order.
 	 */
-	if (ops && ops->add_device && dev->bus && !device_iommu_mapped(dev))
-		err = ops->add_device(dev);
+	if (dev->bus && !device_iommu_mapped(dev))
+		err = iommu_probe_device(dev);
 
 	/* Ignore all other errors apart from EPROBE_DEFER */
 	if (err == -EPROBE_DEFER) {
-------------------------------------------------------------------------------


Git bisection log:

-------------------------------------------------------------------------------
git bisect start
# good: [ddfbab46539f2d37a9e9d357b054486b51f7dc27] Merge tag 'scsi-fixes' of git://git.kernel.org/pub/scm/linux/kernel/git/jejb/scsi
git bisect good ddfbab46539f2d37a9e9d357b054486b51f7dc27
# bad: [02fc169594e96f7c51c4f23114e12b7a18e85a0a] Add linux-next specific files for 20181219
git bisect bad 02fc169594e96f7c51c4f23114e12b7a18e85a0a
# good: [423ff56561dc1c3fdd7c51a6697cc30b8d18d49a] Merge remote-tracking branch 'mtd/mtd/next'
git bisect good 423ff56561dc1c3fdd7c51a6697cc30b8d18d49a
# bad: [232006e511f040f8089f6112916434b0de707c89] Merge remote-tracking branch 'audit/next'
git bisect bad 232006e511f040f8089f6112916434b0de707c89
# good: [02c4fb0210dc2773e0d7f0a5a1b866986f8edc40] Merge branch 'linux-4.21' of git://github.com/skeggsb/linux into drm-next
git bisect good 02c4fb0210dc2773e0d7f0a5a1b866986f8edc40
# good: [7a934f6040a2002e0cbd5507b3b6608537344525] Merge remote-tracking branch 'input/next'
git bisect good 7a934f6040a2002e0cbd5507b3b6608537344525
# good: [36357a3d5a9be1fef1d7ede3bf90bf470bdbbf9f] Merge remote-tracking branch 'device-mapper/for-next'
git bisect good 36357a3d5a9be1fef1d7ede3bf90bf470bdbbf9f
# good: [a85d704d06d9643c5fb3a13744653d6b36c12f8b] Merge remote-tracking branch 'regulator/for-next'
git bisect good a85d704d06d9643c5fb3a13744653d6b36c12f8b
# good: [d5530f072a98f3956a1fc91d800ad85a27c4509b] Merge remote-tracking branch 'watchdog/master'
git bisect good d5530f072a98f3956a1fc91d800ad85a27c4509b
# bad: [d2e1a003af569e912d5f115a3c20b89a19f5caa0] ACPI/IORT: Don't call iommu_ops->add_device directly
git bisect bad d2e1a003af569e912d5f115a3c20b89a19f5caa0
# good: [9b468f7d9cf1f089b7287865776eb100504681b7] iommu/arm-smmu: Use helper functions to access dev->iommu_fwspec
git bisect good 9b468f7d9cf1f089b7287865776eb100504681b7
# good: [170ecbd5ff09aa9c8c1025a8563f76e01a24bb50] iommu/of: Use device_iommu_mapped()
git bisect good 170ecbd5ff09aa9c8c1025a8563f76e01a24bb50
# good: [f884f6ee62604aec60fe1760f94724be192d97c0] dmaengine: sh: rcar-dmac: Use device_iommu_mapped()
git bisect good f884f6ee62604aec60fe1760f94724be192d97c0
# good: [cc5aed44a3a8e4fca721636cf881a52f8d68a098] iommu: Consolitate ->add/remove_device() calls
git bisect good cc5aed44a3a8e4fca721636cf881a52f8d68a098
# bad: [641fb0efbff063ed57f108c2eb4a4d26dbd5badd] iommu/of: Don't call iommu_ops->add_device directly
git bisect bad 641fb0efbff063ed57f108c2eb4a4d26dbd5badd
# first bad commit: [641fb0efbff063ed57f108c2eb4a4d26dbd5badd] iommu/of: Don't call iommu_ops->add_device directly
-------------------------------------------------------------------------------
-------------- next part --------------
@@ -222,10 +222,10 @@ const struct iommu_ops *of_iommu_configure(struct device *dev,
 	/*
 	 * If we have reason to believe the IOMMU driver missed the initial
-	 * add_device callback for dev, replay it to get things in order.
+	 * probe for dev, replay it to get things in order.
 	 */
An HTML attachment was scrubbed...
URL: <http://lists.linuxfoundation.org/pipermail/iommu/attachments/20181219/24063b52/attachment.html>


More information about the iommu mailing list